@@ -1,11 +1,12 @@
 """Main module."""
-from aiohttp import ClientSession
+from datetime import datetime, timedelta
 import logging
-from typing import List, Dict, Any, Optional
+from typing import Any, Dict, List, Optional
+
+from aiohttp import ClientConnectionError, ClientResponseError, ClientSession
+
 from pyclimacell.const import (
     BASE_URL,
-    HEADERS,
-    REALTIME,
     FIELDS,
     FORECAST_DAILY,
     FORECAST_DAILY_MAX_AGE,
@@ -13,13 +14,14 @@ from pyclimacell.const import (
     FORECAST_HOURLY_MAX_AGE,
     FORECAST_NOWCAST,
     FORECAST_NOWCAST_MAX_AGE,
+    HEADERS,
     HISTORICAL_CLIMACELL,
-    HISTORICAL_STATION,
     HISTORICAL_CLIMACELL_MAX_AGE,
+    HISTORICAL_STATION,
     HISTORICAL_STATION_MAX_AGE,
     HISTORICAL_STATION_MAX_INTERVAL,
+    REALTIME,
 )
-from datetime import datetime, timedelta
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -135,23 +137,39 @@ class ClimaCell:
         self, relative_endpoint: str, params: Dict[str, Any]
     ) -> Dict[str, Any]:
         """Call ClimaCell API."""
-        if self.session:
-            resp = await self.session.get(
-                f"{BASE_URL}/{relative_endpoint}",
-                headers=HEADERS,
-                params={**params, **self.params},
-                raise_for_status=True,
-            )
-            return await resp.json()
+        try:
+            if self.session:
+                resp = await self.session.get(
+                    f"{BASE_URL}/{relative_endpoint}",
+                    headers=HEADERS,
+                    params={**params, **self.params},
+                    raise_for_status=True,
+                )
+                return await resp.json()
 
-        async with ClientSession() as session:
-            resp = await session.get(
-                f"{BASE_URL}/{relative_endpoint}",
-                headers=HEADERS,
-                params={**params, **self.params},
-                raise_for_status=True,
-            )
-            return await resp.json()
+            async with ClientSession() as session:
+                resp = await session.get(
+                    f"{BASE_URL}/{relative_endpoint}",
+                    headers=HEADERS,
+                    params={**params, **self.params},
+                    raise_for_status=True,
+                )
+                return await resp.json()
+        except ClientResponseError as e:
+            if e.status == 400:
+                raise MalformedRequestException
+            elif e.status == 401:
+                raise InvalidAPIKeyException
+            elif e.status == 429:
+                raise RateLimitedException
+            else:
+                raise UnknownException
+        except ClientConnectionError as e:
+            raise CantConnectException
+
+    def availabile_fields(self, endpoint: str) -> List[str]:
+        "Return available fields for a given endpoint."
+        return [field for field in FIELDS if endpoint in FIELDS[field]]
 
     async def realtime(self, fields: List[str]) -> Dict[str, Any]:
         """Return realtime weather conditions from ClimaCell API."""
@@ -281,3 +299,23 @@ class ClimaCell:
             end_time,
             duration,
         )
+
+
+class MalformedRequestException(ClientResponseError):
+    """Raised when request was malformed."""
+
+
+class InvalidAPIKeyException(ClientResponseError):
+    """Raised when API key is invalid."""
+
+
+class RateLimitedException(ClientResponseError):
+    """Raised when API rate limit has been exceeded."""
+
+
+class UnknownException(ClientResponseError):
+    """Raised when unknown error occurs."""
+
+
+class CantConnectException(ClientConnectionError):
+    """Raise when client can't connect to ClimaCell API."""
